[libcxx-commits] [PATCH] D115194: [libc++] Fix atomic test for _BitInt

Louis Dionne via Phabricator via libcxx-commits libcxx-commits at lists.llvm.org
Mon Dec 6 19:26:51 PST 2021


ldionne updated this revision to Diff 392263.
ldionne added a comment.

Try to fix CI


Repository:
  rG LLVM Github Monorepo

CHANGES SINCE LAST ACTION
  https://reviews.llvm.org/D115194/new/

https://reviews.llvm.org/D115194

Files:
  libcxx/test/libcxx/atomics/bit-int.verify.cpp
  libcxx/test/libcxx/atomics/ext-int.verify.cpp


Index: libcxx/test/libcxx/atomics/bit-int.verify.cpp
===================================================================
--- libcxx/test/libcxx/atomics/bit-int.verify.cpp
+++ libcxx/test/libcxx/atomics/bit-int.verify.cpp
@@ -8,11 +8,12 @@
 
 // <atomic>
 
 // Make sure that `std::atomic` doesn't work with `_ExtInt`. The intent is to
 // disable them for now until their behavior can be designed better later.
 // See https://reviews.llvm.org/D84049 for details.
 
-// UNSUPPORTED: apple-clang-12
+// UNSUPPORTED: apple-clang-12, apple-clang-13
+// UNSUPPORTED: clang-12, clang-13
 
 // UNSUPPORTED: c++03
 
@@ -20,8 +21,8 @@
 
 int main(int, char**)
 {
-  // expected-error at atomic:*1 {{_Atomic cannot be applied to integer type '_ExtInt(32)'}}
-  std::atomic<_ExtInt(32)> x(42);
+  // expected-error at atomic:*1 {{_Atomic cannot be applied to integer type '_BitInt(32)'}}
+  std::atomic<_BitInt(32)> x(42);
 
   return 0;
 }


-------------- next part --------------
@@ -8,11 +8,12 @@
 // <atomic>
 
-// Make sure that `std::atomic` doesn't work with `_ExtInt`. The intent is to
+// Make sure that `std::atomic` doesn't work with `_BitInt`. The intent is to
 // disable them for now until their behavior can be designed better later.
 // See https://reviews.llvm.org/D84049 for details.
A non-text attachment was scrubbed...
Name: D115194.392263.patch
Type: text/x-patch
Size: 1004 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/libcxx-commits/attachments/20211207/ad3cdcc3/attachment.bin>


More information about the libcxx-commits mailing list